@@ -3,14 +3,14 @@
 import os
 import sys
 
-from lintian_brush.control import (
+from debmutate.control import (
     add_dependency,
-    ControlUpdater,
+    ControlEditor,
     )
-from lintian_brush.debhelper import (
+from debmutate.debhelper import (
     get_debhelper_compat_level,
     )
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 
 compat_version = get_debhelper_compat_level()
@@ -25,7 +25,7 @@ added = set()
 # Add Pre-Depends: ${misc:Pre-Depends} iff:
 # - a package has both a init script and a (ubuntu | systemd) unit
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     for binary in updater.binaries:
         name = binary["Package"]
         if not os.path.exists('debian/%s.init' % name):
@@ -39,9 +39,10 @@ with ControlUpdater() as updater:
             binary.get("Pre-Depends", ""),
             "${misc:Pre-Depends}")
         added.add(name)
+        fixed_lintian_tag(
+            updater.source, 'skip-systemd-native-flag-missing-pre-depends')
 
 
 report_result(
     "Add missing Pre-Depends: ${misc:Pre-Depends} in %s." %
-    ", ".join(sorted(added)),
-    fixed_lintian_tags=['skip-systemd-native-flag-missing-pre-depends'])
+    ", ".join(sorted(added)))
